/*
 * File: Door.cs
 * Date: 04 nov 2012
 * Time: 15:47:24
 * Generated by TismTool version 0.9
 */

/*
 * Overview of identifications
 * ---------------------------
 * Ports:
 *     10 ( Xmi > Data > Protocols > DoorCheckProtocol > Client > Port )
 *     34 ( Xmi > Data > Protocols > DoorCheckProtocol > Server > Port )
 * Triggers:
 *      1 void ICbDoor___CbOpened( int responseId )
 *      2 void ICbDoor___CbClosed( int responseId )
 *      3 void IDoor___Open( int requestId )
 *      4 void IDoor___Close( int requestId )
 * Natives:
 *    -21 ( ClientCheckPsm >> Closed ) ->
 *        ( ClientCheckPsm >> Opening )
 *        Open(++requestId);
 *    -22 ( ClientCheckPsm >> Opened ) ->
 *        ( ClientCheckPsm >> Closing )
 *        Close(++requestId);
 *    -23 ( ClientCheckPsm >> Opening ) ->
 *        ( ClientCheckPsm >> Closing )
 *        Close(++requestId);
 *    -24 ( ClientCheckPsm >> Closing ) ->
 *        ( ClientCheckPsm >> Opening )
 *        Open(++requestId);
 *     44 ( ServerCheckPsm >> Opening ) ->
 *        ( ServerCheckPsm >> Opened )
 *        CbOpened(responseId);
 *     46 ( ServerCheckPsm >> Closing ) ->
 *        ( ServerCheckPsm >> Closed )
 *        CbClosed(responseId);
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using TsmRTE;

namespace Door
{
  public partial class Door
  {
    static void ArgsHandle( string[] args )
    {
      for ( int i=0; i<args.Length; i++ )
      {
        char [] ca = args[ i ].ToCharArray();
        if ( ( ca.Length >= 2 ) && ( ca[ 0 ] == '-' ) )
        {
          switch ( ca[1] )
          {
          case 'l' :
            if ( ( ca.Length >= 4 ) && ( ca[ 2 ] == '=' ) )
            {
              int ll = Convert.ToInt32( args[ i ].Substring( 3 ) );
              Tsm.SetLogLevel( ll );
            }
            break;
          case 'C' :
            if ( ca.Length >= 3 )
            {
              Tsm.SetLogConsole( ca[ 2 ] == '+' );
            }
            break;
          case 'L' :
            if ( ca.Length >= 3 )
            {
              Tsm.SetLogFile( ca[ 2 ] == '+' );
            }
            break;
          case 'S' :
            if ( ca.Length >= 3 )
            {
              Tsm.SetSeqFile( ca[ 2 ] == '+' );
            }
            break;
          }
        }
      }
    }

    static void Main( string[] args )
    {
      ArgsHandle( args );
      try
      {
        TsmSystem ts = new TsmSystem( null );
        ts.Activate();
        ts.Execute();
        ts.Deactivate();
      }
      catch ( Exception exc )
      {
        Tsm.Log( "*** TsmSystem Exception ***" );
        Tsm.Log( exc.Message );
        Tsm.Log( exc.StackTrace );
      }
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Repository > Door )
   ********************************************************************/

   // ( Xmi > Data > Repository > Door )
  public class Pac_0002_0003 : TsmPackage
  {
    public Pac_0002_0003( TsmBase oParent )
    {
      TsmName = "Door";
      TsmParent = oParent;
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Repository )
   ********************************************************************/

   // ( Xmi > Data > Repository )
  public class Pac_0001_0002 : TsmPackage
  {
    public Pac_0001_0002( TsmBase oParent )
    {
      TsmName = "Repository";
      TsmParent = oParent;
    }
  }

  public interface IDoor
  {
    void Open( int requestId );
    void Close( int requestId );
  }

  public class TsmTrigger_IDoor___Open : TsmTrigger
  {
    public int requestId;

    public TsmTrigger_IDoor___Open( int requestId )
      : base( 3 )
    {
      this.requestId = requestId;
    }
  }

  public class TsmTrigger_IDoor___Close : TsmTrigger
  {
    public int requestId;

    public TsmTrigger_IDoor___Close( int requestId )
      : base( 4 )
    {
      this.requestId = requestId;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > IDoor )
  public class TsmIPort_IDoor : TsmInterfacePort, IDoor
  {
    public TsmIPort_IDoor( TsmBase oParent )
    {
      TsmName = "IDoor";
      TsmParent = oParent;
    }

    public virtual void Open( int requestId )
    {
      TsmTrigger_IDoor___Open tt = new TsmTrigger_IDoor___Open( requestId );
      TsmRecorder.AddCall( "Open", this.Source, this.Messager );
      tt.PortId = this.PortId;
      tt.IsForeign = (this.Source==null);
      this.Messager.Handle( tt );
    }

    public virtual void Close( int requestId )
    {
      TsmTrigger_IDoor___Close tt = new TsmTrigger_IDoor___Close( requestId );
      TsmRecorder.AddCall( "Close", this.Source, this.Messager );
      tt.PortId = this.PortId;
      tt.IsForeign = (this.Source==null);
      this.Messager.Handle( tt );
    }
  }

  public interface ICbDoor
  {
    void CbOpened( int responseId );
    void CbClosed( int responseId );
  }

  public class TsmTrigger_ICbDoor___CbOpened : TsmTrigger
  {
    public int responseId;

    public TsmTrigger_ICbDoor___CbOpened( int responseId )
      : base( 1 )
    {
      this.responseId = responseId;
    }
  }

  public class TsmTrigger_ICbDoor___CbClosed : TsmTrigger
  {
    public int responseId;

    public TsmTrigger_ICbDoor___CbClosed( int responseId )
      : base( 2 )
    {
      this.responseId = responseId;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > ICbDoor )
  public class TsmIPort_ICbDoor : TsmInterfacePort, ICbDoor
  {
    public TsmIPort_ICbDoor( TsmBase oParent )
    {
      TsmName = "ICbDoor";
      TsmParent = oParent;
    }

    public virtual void CbOpened( int responseId )
    {
      TsmTrigger_ICbDoor___CbOpened tt = new TsmTrigger_ICbDoor___CbOpened( responseId );
      TsmRecorder.AddCall( "CbOpened", this.Source, this.Messager );
      tt.PortId = this.PortId;
      tt.IsForeign = (this.Source==null);
      this.Messager.Handle( tt );
    }

    public virtual void CbClosed( int responseId )
    {
      TsmTrigger_ICbDoor___CbClosed tt = new TsmTrigger_ICbDoor___CbClosed( responseId );
      TsmRecorder.AddCall( "CbClosed", this.Source, this.Messager );
      tt.PortId = this.PortId;
      tt.IsForeign = (this.Source==null);
      this.Messager.Handle( tt );
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> InitialState )
  public class Ini_0012_0013 : TsmPseudo
  {
    public Ini_0012_0013( TsmBase oParent )
    {
      TsmName = "InitialState";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 20, "( ClientCheckPsm >> InitialState ) => ( ClientCheckPsm >> Closed )" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 20; // TRLS ( ClientCheckPsm >> InitialState ) => ( ClientCheckPsm >> Closed )
      mTransitions[ 0 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 20: // UP: ( ClientCheckPsm >> InitialState ) => ( ClientCheckPsm >> Closed )
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> ChoiceState )
  public class Cho_0012_0014 : TsmPseudo
  {
    public Cho_0012_0014( TsmBase oParent )
    {
      TsmName = "ChoiceState";
      TsmParent = oParent;
      mNrTransitions = 2;
      mTransitions = new TsmTransition[ 2 ];
      mTransitions[ 0 ] = new TsmTransition( 28, "( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opened )" );
      mTransitions[ 1 ] = new TsmTransition( 29, "( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opening )" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      TsmTrigger_ICbDoor___CbOpened lTrigger = (TsmTrigger_ICbDoor___CbOpened) oHandler.Trigger;
      int responseId = lTrigger.responseId;

      if ( ((Cla_0005_0009)oHandler.Owner).Guard_1002( responseId ) )
      {
        oHandler.Action = TsmHandlerAction.TRANSITION;
        oHandler.Index  = 28; // TRLS ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opened )
        mTransitions[ 0 ].bVisit = true;
      }
      else
      {
        oHandler.Action = TsmHandlerAction.TRANSITION;
        oHandler.Index  = 29; // TRLS ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opening )
        mTransitions[ 1 ].bVisit = true;
      }
    }

    public void Tra_0012_0027( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 28: // UP: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opened )
        bHigher = true;
        break;
      case 29: // UP: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opening )
        bHigher = true;
        break;
      case 27:
        Tra_0012_0027( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> ChoiceState )
  public class Cho_0012_0015 : TsmPseudo
  {
    public Cho_0012_0015( TsmBase oParent )
    {
      TsmName = "ChoiceState";
      TsmParent = oParent;
      mNrTransitions = 2;
      mTransitions = new TsmTransition[ 2 ];
      mTransitions[ 0 ] = new TsmTransition( 31, "( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closed )" );
      mTransitions[ 1 ] = new TsmTransition( 32, "( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closing )" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      TsmTrigger_ICbDoor___CbClosed lTrigger = (TsmTrigger_ICbDoor___CbClosed) oHandler.Trigger;
      int responseId = lTrigger.responseId;

      if ( ((Cla_0005_0009)oHandler.Owner).Guard_1003( responseId ) )
      {
        oHandler.Action = TsmHandlerAction.TRANSITION;
        oHandler.Index  = 31; // TRLS ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closed )
        mTransitions[ 0 ].bVisit = true;
      }
      else
      {
        oHandler.Action = TsmHandlerAction.TRANSITION;
        oHandler.Index  = 32; // TRLS ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closing )
        mTransitions[ 1 ].bVisit = true;
      }
    }

    public void Tra_0012_0030( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 31: // UP: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closed )
        bHigher = true;
        break;
      case 32: // UP: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closing )
        bHigher = true;
        break;
      case 30:
        Tra_0012_0030( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Closed )
  public class Lea_0012_0016 : TsmLeaf
  {
    int [] aNatives = { -21 };

    public Lea_0012_0016( TsmBase oParent )
    {
      TsmName = "Closed";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 21, "( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening )" );
    }

    public void Tra_0012_0020( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0012_0031( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 21:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 21: // Native: ( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening )
          TsmRecorder.AddNative( "( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening ) # Open(++requestId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 21;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 20:
        Tra_0012_0020( oHandler );
        break;
      case 31:
        Tra_0012_0031( oHandler );
        break;
      case 21: // UP: ( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening )
        AtExit( oHandler );
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Opening )
  public class Lea_0012_0017 : TsmLeaf
  {
    int [] aNatives = { -23 };

    public Lea_0012_0017( TsmBase oParent )
    {
      TsmName = "Opening";
      TsmParent = oParent;
      mNrTransitions = 3;
      mTransitions = new TsmTransition[ 3 ];
      mTransitions[ 0 ] = new TsmTransition( 23, "( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing )" );
      mTransitions[ 1 ] = new TsmTransition( 27, "( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> ChoiceState ) : CbOpened" );
      mTransitions[ 2 ] = new TsmTransition( 26, "( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Opening ) : CbClosed" );
    }

    public void Tra_0012_0029( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Tra_0012_0021( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0012_0024( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Port___CbOpened( int responseId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 27; // CbOpened
      oHandler.bTaken = true;
      mTransitions[ 1 ].bVisit = true;
    }

    public void Tra_0012_0026( TsmHandler oHandler )
    {
      oHandler.bTaken = true;
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Port___CbClosed( int responseId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 26; // CbClosed
      oHandler.bTaken = true;
      mTransitions[ 2 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 23:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 10:
        switch ( Command )
        {
        case 1:
          return TsmProspect.OK;
        case 2:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 23: // Native: ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing )
          TsmRecorder.AddNative( "( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing ) # Close(++requestId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 23;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break; // end of Port -1
      case 10: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 1: // Port___CbOpened
          {
            TsmTrigger_ICbDoor___CbOpened lTrigger = (TsmTrigger_ICbDoor___CbOpened) oHandler.Trigger;

            Port___CbOpened( lTrigger.responseId, oHandler );
          }
          break;
        case 2: // Port___CbClosed
          {
            TsmTrigger_ICbDoor___CbClosed lTrigger = (TsmTrigger_ICbDoor___CbClosed) oHandler.Trigger;

            Port___CbClosed( lTrigger.responseId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 29:
        Tra_0012_0029( oHandler );
        break;
      case 21:
        Tra_0012_0021( oHandler );
        break;
      case 23: // UP: ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 24:
        Tra_0012_0024( oHandler );
        break;
      case 27: // UP: ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> ChoiceState )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 26:
        Tra_0012_0026( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Opened )
  public class Lea_0012_0018 : TsmLeaf
  {
    int [] aNatives = { -22 };

    public Lea_0012_0018( TsmBase oParent )
    {
      TsmName = "Opened";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 22, "( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing )" );
    }

    public void Tra_0012_0028( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 22:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 22: // Native: ( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing )
          TsmRecorder.AddNative( "( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing ) # Close(++requestId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 22;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 28:
        Tra_0012_0028( oHandler );
        break;
      case 22: // UP: ( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing )
        AtExit( oHandler );
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Closing )
  public class Lea_0012_0019 : TsmLeaf
  {
    int [] aNatives = { -24 };

    public Lea_0012_0019( TsmBase oParent )
    {
      TsmName = "Closing";
      TsmParent = oParent;
      mNrTransitions = 3;
      mTransitions = new TsmTransition[ 3 ];
      mTransitions[ 0 ] = new TsmTransition( 24, "( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening )" );
      mTransitions[ 1 ] = new TsmTransition( 25, "( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Closing ) : CbOpened" );
      mTransitions[ 2 ] = new TsmTransition( 30, "( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> ChoiceState ) : CbClosed" );
    }

    public void Tra_0012_0032( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Tra_0012_0023( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0012_0022( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0012_0025( TsmHandler oHandler )
    {
      oHandler.bTaken = true;
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Port___CbOpened( int responseId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 25; // CbOpened
      oHandler.bTaken = true;
      mTransitions[ 1 ].bVisit = true;
    }

    public void Port___CbClosed( int responseId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 30; // CbClosed
      oHandler.bTaken = true;
      mTransitions[ 2 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 24:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 10:
        switch ( Command )
        {
        case 1:
          return TsmProspect.OK;
        case 2:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 24: // Native: ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening )
          TsmRecorder.AddNative( "( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening ) # Open(++requestId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 24;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break; // end of Port -1
      case 10: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 1: // Port___CbOpened
          {
            TsmTrigger_ICbDoor___CbOpened lTrigger = (TsmTrigger_ICbDoor___CbOpened) oHandler.Trigger;

            Port___CbOpened( lTrigger.responseId, oHandler );
          }
          break;
        case 2: // Port___CbClosed
          {
            TsmTrigger_ICbDoor___CbClosed lTrigger = (TsmTrigger_ICbDoor___CbClosed) oHandler.Trigger;

            Port___CbClosed( lTrigger.responseId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 32:
        Tra_0012_0032( oHandler );
        break;
      case 23:
        Tra_0012_0023( oHandler );
        break;
      case 22:
        Tra_0012_0022( oHandler );
        break;
      case 24: // UP: ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 25:
        Tra_0012_0025( oHandler );
        break;
      case 30: // UP: ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> ChoiceState )
        AtExit( oHandler );
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >)
  public class Reg_0011_0012 : TsmRegion
  {
    private Ini_0012_0013 oIni_0012_0013; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> InitialState )
    private Cho_0012_0014 oCho_0012_0014; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> ChoiceState )
    private Cho_0012_0015 oCho_0012_0015; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> ChoiceState )
    private Lea_0012_0016 oLea_0012_0016; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Closed )
    private Lea_0012_0017 oLea_0012_0017; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Opening )
    private Lea_0012_0018 oLea_0012_0018; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Opened )
    private Lea_0012_0019 oLea_0012_0019; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >> Closing )

    public Reg_0011_0012( TsmBase oParent )
    {
      TsmName = "";
      TsmParent = oParent;
      oIni_0012_0013 = new Ini_0012_0013( this );
      oCho_0012_0014 = new Cho_0012_0014( this );
      oCho_0012_0015 = new Cho_0012_0015( this );
      oLea_0012_0016 = new Lea_0012_0016( this );
      oLea_0012_0017 = new Lea_0012_0017( this );
      oLea_0012_0018 = new Lea_0012_0018( this );
      oLea_0012_0019 = new Lea_0012_0019( this );
      mNrStates = 7;
      mStates = new TsmState[ mNrStates ];
      mStates[ 0 ] = oIni_0012_0013;
      mStates[ 1 ] = oCho_0012_0014;
      mStates[ 2 ] = oCho_0012_0015;
      mStates[ 3 ] = oLea_0012_0016;
      mStates[ 4 ] = oLea_0012_0017;
      mStates[ 5 ] = oLea_0012_0018;
      mStates[ 6 ] = oLea_0012_0019;
    }

    public override void Initial( TsmHandler oHandler )
    {
      mbFinal = false;
      oHandler.Action = TsmHandlerAction.ENTER;
      oIni_0012_0013.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> InitialState ) => ( ClientCheckPsm >> Closed )
    public void Tra_0012_0020( TsmHandler oHandler )
    {
      ((Cla_0005_0009)oHandler.Owner).Function_1001( oHandler );
      mCurrentState = oLea_0012_0016; // At: ( ClientCheckPsm >> Closed )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opened )
    public void Tra_0012_0028( TsmHandler oHandler )
    {
      mCurrentState = oLea_0012_0018; // At: ( ClientCheckPsm >> Opened )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Opening )
    public void Tra_0012_0029( TsmHandler oHandler )
    {
      mCurrentState = oLea_0012_0017; // At: ( ClientCheckPsm >> Opening )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closed )
    public void Tra_0012_0031( TsmHandler oHandler )
    {
      mCurrentState = oLea_0012_0016; // At: ( ClientCheckPsm >> Closed )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> ChoiceState ) => ( ClientCheckPsm >> Closing )
    public void Tra_0012_0032( TsmHandler oHandler )
    {
      mCurrentState = oLea_0012_0019; // At: ( ClientCheckPsm >> Closing )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening )
    public void Tra_0012_0021( TsmHandler oHandler )
    {
      ((Cla_0005_0009)oHandler.Owner).Function_1004( oHandler );
      mCurrentState = oLea_0012_0017; // At: ( ClientCheckPsm >> Opening )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing )
    public void Tra_0012_0023( TsmHandler oHandler )
    {
      ((Cla_0005_0009)oHandler.Owner).Function_1005( oHandler );
      mCurrentState = oLea_0012_0019; // At: ( ClientCheckPsm >> Closing )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing )
    public void Tra_0012_0022( TsmHandler oHandler )
    {
      ((Cla_0005_0009)oHandler.Owner).Function_1006( oHandler );
      mCurrentState = oLea_0012_0019; // At: ( ClientCheckPsm >> Closing )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening )
    public void Tra_0012_0024( TsmHandler oHandler )
    {
      ((Cla_0005_0009)oHandler.Owner).Function_1007( oHandler );
      mCurrentState = oLea_0012_0017; // At: ( ClientCheckPsm >> Opening )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> ChoiceState )
    public void Tra_0012_0027( TsmHandler oHandler )
    {
      mCurrentState = oCho_0012_0014; // At: ( ClientCheckPsm >> ChoiceState )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> ChoiceState )
    public void Tra_0012_0030( TsmHandler oHandler )
    {
      mCurrentState = oCho_0012_0015; // At: ( ClientCheckPsm >> ChoiceState )
      mCurrentState.ExecuteHandler( oHandler );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 21:
          return TsmProspect.OK;
        case 23:
          return TsmProspect.OK;
        case 22:
          return TsmProspect.OK;
        case 24:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 10:
        switch ( Command )
        {
        case 1:
          return TsmProspect.OK;
        case 2:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 20:
        Tra_0012_0020( oHandler );
        break;
      case 28:
        Tra_0012_0028( oHandler );
        break;
      case 29:
        Tra_0012_0029( oHandler );
        break;
      case 31:
        Tra_0012_0031( oHandler );
        break;
      case 32:
        Tra_0012_0032( oHandler );
        break;
      case 21:
        Tra_0012_0021( oHandler );
        break;
      case 23:
        Tra_0012_0023( oHandler );
        break;
      case 22:
        Tra_0012_0022( oHandler );
        break;
      case 24:
        Tra_0012_0024( oHandler );
        break;
      case 27:
        Tra_0012_0027( oHandler );
        break;
      case 30:
        Tra_0012_0030( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm )
  public class Fsm_0009_0011 : TsmFsm
  {
    private Reg_0011_0012 oReg_0011_0012; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm >)

    public Fsm_0009_0011( TsmBase oParent )
    {
      TsmName = "ClientCheckPsm";
      TsmParent = oParent;
      oReg_0011_0012 = new Reg_0011_0012( this );
      mRegions.Add( oReg_0011_0012 );
      mNrTransitions = 0;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Client )
  public class Cla_0005_0009 : TsmProtocolClass
  {
    private Fsm_0009_0011 oFsm_0009_0011; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > ClientCheckPsm )
    private TsmIPort_IDoor Port; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > Port )
    private TsmIPort_ICbDoor TsmPI__Port; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > Port )
    private TsmPCPort mPCMessager;
    private int requestId = 0;

    public Cla_0005_0009( TsmBase oParent, string sInstanceName )
    {
      TsmName = sInstanceName;
      TsmParent = oParent;
      oFsm_0009_0011 = new Fsm_0009_0011( this );
      TsmPI__Port = new TsmIPort_ICbDoor( this );
      mPCMessager = new TsmPCPort();
      oFsms = new TsmFsm[ 1 ];
      oFsms[ 0 ] = oFsm_0009_0011;
    }

    public override TsmInterfacePort GetProvidedInterface( string sPortName )
    {
      switch( sPortName )
      {
      case "Port" :
        return TsmPI__Port;
      default :
        break;
      }
      string s;
      s = "No port '" + sPortName + "' @ ( Xmi > Data > Protocols > DoorCheckProtocol > Client )";
      throw new TsmException( s );
    }

    public override void SetRequiredInterface( string sPortName, TsmInterfacePort oProvidedInterface )
    {
      switch( sPortName )
      {
      case "Port" :
        Port = (TsmIPort_IDoor) oProvidedInterface;
        Port.Source = this;
        return;
      default :
        break;
      }
      string s;
      s = "No port '" + sPortName + "' @ ( Xmi > Data > Protocols > DoorCheckProtocol > Client )";
      throw new TsmException( s );
    }

    public override void ExecuteTrigger( TsmTrigger oTrigger )
    {
      SnapCall = oTrigger.Snap();
      TsmHandler lHandler = new TsmHandler( this, oTrigger );
      oFsm_0009_0011.ExecuteTriggerFsm( lHandler );
      SnapCall = "";
      SnapState = null;
    }

     // ( ClientCheckPsm >> InitialState ) => ( ClientCheckPsm >> Closed )
    public void Function_1001( TsmHandler oHandler )
    {
      requestId = 0;
    }

    public bool Guard_1002( int responseId )
    {
      return responseId
    ==
    requestId;
    }

    public bool Guard_1003( int responseId )
    {
      return responseId
    ==
    requestId;
    }

     // ( ClientCheckPsm >> Closed ) => ( ClientCheckPsm >> Opening )
    public void Function_1004( TsmHandler oHandler )
    {
      Port.Open(++requestId);
    }

     // ( ClientCheckPsm >> Opening ) => ( ClientCheckPsm >> Closing )
    public void Function_1005( TsmHandler oHandler )
    {
      Port.Close(++requestId);
    }

     // ( ClientCheckPsm >> Opened ) => ( ClientCheckPsm >> Closing )
    public void Function_1006( TsmHandler oHandler )
    {
      Port.Close(++requestId);
    }

     // ( ClientCheckPsm >> Closing ) => ( ClientCheckPsm >> Opening )
    public void Function_1007( TsmHandler oHandler )
    {
      Port.Open(++requestId);
    }

    public override void TsmInitialise( object oObject )
    {
      TsmPI__Port.PortId = 10;
      TsmPI__Port.Messager = mPCMessager;
    }

    public override void TsmConnect( object oObject )
    {
      mPCMessager.Target = this;
      mPCMessager.IntQueue = (TsmIntQueue) oObject;
    }

    public override void TsmPrepare( object oObject )
    {
      TsmHandler lHandler = new TsmHandler( this );
      lHandler.Action = TsmHandlerAction.ENTER;
      oFsm_0009_0011.ExecuteHandler( lHandler );
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> InitialState )
  public class Ini_0036_0037 : TsmPseudo
  {
    public Ini_0036_0037( TsmBase oParent )
    {
      TsmName = "InitialState";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 42, "( ServerCheckPsm >> InitialState ) => ( ServerCheckPsm >> Closed )" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 42; // TRLS ( ServerCheckPsm >> InitialState ) => ( ServerCheckPsm >> Closed )
      mTransitions[ 0 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 42: // UP: ( ServerCheckPsm >> InitialState ) => ( ServerCheckPsm >> Closed )
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Closed )
  public class Lea_0036_0038 : TsmLeaf
  {
    public Lea_0036_0038( TsmBase oParent )
    {
      TsmName = "Closed";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 43, "( ServerCheckPsm >> Closed ) => ( ServerCheckPsm >> Opening ) : Open" );
    }

    public void Tra_0036_0042( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Tra_0036_0046( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Port___Open( int requestId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 43; // Open
      oHandler.bTaken = true;
      mTransitions[ 0 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case 34:
        switch ( Command )
        {
        case 3:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case 34: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 3: // Port___Open
          {
            TsmTrigger_IDoor___Open lTrigger = (TsmTrigger_IDoor___Open) oHandler.Trigger;

            Port___Open( lTrigger.requestId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 42:
        Tra_0036_0042( oHandler );
        break;
      case 46:
        Tra_0036_0046( oHandler );
        break;
      case 43: // UP: ( ServerCheckPsm >> Closed ) => ( ServerCheckPsm >> Opening )
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Opening )
  public class Lea_0036_0039 : TsmLeaf
  {
    int [] aNatives = { 44 };

    public Lea_0036_0039( TsmBase oParent )
    {
      TsmName = "Opening";
      TsmParent = oParent;
      mNrTransitions = 2;
      mTransitions = new TsmTransition[ 2 ];
      mTransitions[ 0 ] = new TsmTransition( 44, "( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened )" );
      mTransitions[ 1 ] = new TsmTransition( 47, "( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Closing ) : Close" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Tra_0036_0043( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0036_0048( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Port___Close( int requestId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 47; // Close
      oHandler.bTaken = true;
      mTransitions[ 1 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 44:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 34:
        switch ( Command )
        {
        case 4:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 44: // Native: ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened )
          TsmRecorder.AddNative( "( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened ) # CbOpened(responseId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 44;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break; // end of Port -1
      case 34: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 4: // Port___Close
          {
            TsmTrigger_IDoor___Close lTrigger = (TsmTrigger_IDoor___Close) oHandler.Trigger;

            Port___Close( lTrigger.requestId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 44: // UP: ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 43:
        Tra_0036_0043( oHandler );
        break;
      case 48:
        Tra_0036_0048( oHandler );
        break;
      case 47: // UP: ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Closing )
        AtExit( oHandler );
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Opened )
  public class Lea_0036_0040 : TsmLeaf
  {
    public Lea_0036_0040( TsmBase oParent )
    {
      TsmName = "Opened";
      TsmParent = oParent;
      mNrTransitions = 1;
      mTransitions = new TsmTransition[ 1 ];
      mTransitions[ 0 ] = new TsmTransition( 45, "( ServerCheckPsm >> Opened ) => ( ServerCheckPsm >> Closing ) : Close" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Tra_0036_0044( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Port___Close( int requestId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 45; // Close
      oHandler.bTaken = true;
      mTransitions[ 0 ].bVisit = true;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case 34:
        switch ( Command )
        {
        case 4:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case 34: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 4: // Port___Close
          {
            TsmTrigger_IDoor___Close lTrigger = (TsmTrigger_IDoor___Close) oHandler.Trigger;

            Port___Close( lTrigger.requestId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 44:
        Tra_0036_0044( oHandler );
        break;
      case 45: // UP: ( ServerCheckPsm >> Opened ) => ( ServerCheckPsm >> Closing )
        bHigher = true;
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Closing )
  public class Lea_0036_0041 : TsmLeaf
  {
    int [] aNatives = { 46 };

    public Lea_0036_0041( TsmBase oParent )
    {
      TsmName = "Closing";
      TsmParent = oParent;
      mNrTransitions = 2;
      mTransitions = new TsmTransition[ 2 ];
      mTransitions[ 0 ] = new TsmTransition( 46, "( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed )" );
      mTransitions[ 1 ] = new TsmTransition( 48, "( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Opening ) : Open" );
    }

    public override void Initial( TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.OK;
    }

    public void Port___Open( int requestId, TsmHandler oHandler )
    {
      oHandler.Action = TsmHandlerAction.TRANSITION;
      oHandler.Index  = 48; // Open
      oHandler.bTaken = true;
      mTransitions[ 1 ].bVisit = true;
    }

    public void Tra_0036_0047( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public void Tra_0036_0045( TsmHandler oHandler )
    {
      AtEntry( oHandler );
      Initial( oHandler );
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
      TsmSupervisor.NativeEntry( oHandler.Owner, aNatives );
    }

    public override void AtExit( TsmHandler oHandler )
    {
      TsmSupervisor.NativeExit( oHandler.Owner, aNatives );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 46:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 34:
        switch ( Command )
        {
        case 3:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override void ExecuteTrigger( TsmHandler oHandler )
    {
      switch ( oHandler.Trigger.PortId )
      {
      case -1: // Port NativePort
        switch ( oHandler.Trigger.Command )
        {
        case 46: // Native: ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed )
          TsmRecorder.AddNative( "( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed ) # CbClosed(responseId);" );
          oHandler.Action = TsmHandlerAction.TRANSITION;
          oHandler.Index  = 46;
          oHandler.bTaken = true;
          mTransitions[ 0 ].bVisit = true;
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break; // end of Port -1
      case 34: // Port Port
        switch ( oHandler.Trigger.Command )
        {
        case 3: // Port___Open
          {
            TsmTrigger_IDoor___Open lTrigger = (TsmTrigger_IDoor___Open) oHandler.Trigger;

            Port___Open( lTrigger.requestId, oHandler );
          }
          break;
        default:
          oHandler.Action = TsmHandlerAction.NOK;
          break;
        }
        break;
      default:
        oHandler.Action = TsmHandlerAction.NOK;
        break;
      }
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 46: // UP: ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 48: // UP: ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Opening )
        AtExit( oHandler );
        bHigher = true;
        break;
      case 47:
        Tra_0036_0047( oHandler );
        break;
      case 45:
        Tra_0036_0045( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >)
  public class Reg_0035_0036 : TsmRegion
  {
    private Ini_0036_0037 oIni_0036_0037; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> InitialState )
    private Lea_0036_0038 oLea_0036_0038; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Closed )
    private Lea_0036_0039 oLea_0036_0039; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Opening )
    private Lea_0036_0040 oLea_0036_0040; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Opened )
    private Lea_0036_0041 oLea_0036_0041; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >> Closing )

    public Reg_0035_0036( TsmBase oParent )
    {
      TsmName = "";
      TsmParent = oParent;
      oIni_0036_0037 = new Ini_0036_0037( this );
      oLea_0036_0038 = new Lea_0036_0038( this );
      oLea_0036_0039 = new Lea_0036_0039( this );
      oLea_0036_0040 = new Lea_0036_0040( this );
      oLea_0036_0041 = new Lea_0036_0041( this );
      mNrStates = 5;
      mStates = new TsmState[ mNrStates ];
      mStates[ 0 ] = oIni_0036_0037;
      mStates[ 1 ] = oLea_0036_0038;
      mStates[ 2 ] = oLea_0036_0039;
      mStates[ 3 ] = oLea_0036_0040;
      mStates[ 4 ] = oLea_0036_0041;
    }

    public override void Initial( TsmHandler oHandler )
    {
      mbFinal = false;
      oHandler.Action = TsmHandlerAction.ENTER;
      oIni_0036_0037.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> InitialState ) => ( ServerCheckPsm >> Closed )
    public void Tra_0036_0042( TsmHandler oHandler )
    {
      mCurrentState = oLea_0036_0038; // At: ( ServerCheckPsm >> Closed )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened )
    public void Tra_0036_0044( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1008( oHandler );
      mCurrentState = oLea_0036_0040; // At: ( ServerCheckPsm >> Opened )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed )
    public void Tra_0036_0046( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1009( oHandler );
      mCurrentState = oLea_0036_0038; // At: ( ServerCheckPsm >> Closed )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Closed ) => ( ServerCheckPsm >> Opening )
    public void Tra_0036_0043( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1010( oHandler );
      mCurrentState = oLea_0036_0039; // At: ( ServerCheckPsm >> Opening )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Opening )
    public void Tra_0036_0048( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1011( oHandler );
      mCurrentState = oLea_0036_0039; // At: ( ServerCheckPsm >> Opening )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Closing )
    public void Tra_0036_0047( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1012( oHandler );
      mCurrentState = oLea_0036_0041; // At: ( ServerCheckPsm >> Closing )
      mCurrentState.ExecuteHandler( oHandler );
    }

     // At: ( ServerCheckPsm >> Opened ) => ( ServerCheckPsm >> Closing )
    public void Tra_0036_0045( TsmHandler oHandler )
    {
      ((Cla_0005_0033)oHandler.Owner).Function_1013( oHandler );
      mCurrentState = oLea_0036_0041; // At: ( ServerCheckPsm >> Closing )
      mCurrentState.ExecuteHandler( oHandler );
    }

    public override TsmProspect GetProspect( int PortId, int Command )
    {
      switch ( PortId )
      {
      case -1:
        switch ( Command )
        {
        case 44:
          return TsmProspect.OK;
        case 46:
          return TsmProspect.OK;
        default:
          break;
        }
        break; // end of Port -1
      case 34:
        switch ( Command )
        {
        case 3:
          return TsmProspect.OK;
        case 4:
          return TsmProspect.OK;
        default:
          break;
        }
        break;
      default:
        break;
      }

      return TsmProspect.NOK;
    }

    public override bool ExecuteTransition( TsmHandler oHandler )
    {
      bool bHigher = false;
      switch ( oHandler.Index )
      {
      case 42:
        Tra_0036_0042( oHandler );
        break;
      case 44:
        Tra_0036_0044( oHandler );
        break;
      case 46:
        Tra_0036_0046( oHandler );
        break;
      case 43:
        Tra_0036_0043( oHandler );
        break;
      case 48:
        Tra_0036_0048( oHandler );
        break;
      case 47:
        Tra_0036_0047( oHandler );
        break;
      case 45:
        Tra_0036_0045( oHandler );
        break;
      default:
        throw new TsmException( "Unknown Index " + oHandler.Index );
      }
      return bHigher;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm )
  public class Fsm_0033_0035 : TsmFsm
  {
    private Reg_0035_0036 oReg_0035_0036; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm >)

    public Fsm_0033_0035( TsmBase oParent )
    {
      TsmName = "ServerCheckPsm";
      TsmParent = oParent;
      oReg_0035_0036 = new Reg_0035_0036( this );
      mRegions.Add( oReg_0035_0036 );
      mNrTransitions = 0;
    }

    public override void AtEntry( TsmHandler oHandler )
    {
      bVisit = true;
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > Server )
  public class Cla_0005_0033 : TsmProtocolClass
  {
    private Fsm_0033_0035 oFsm_0033_0035; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > ServerCheckPsm )
    private TsmIPort_IDoor TsmPI__Port; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > Port )
    private TsmIPort_ICbDoor Port; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > Port )
    private TsmPSPort mPSMessager;
    private int responseId = 0;

    public Cla_0005_0033( TsmBase oParent, string sInstanceName )
    {
      TsmName = sInstanceName;
      TsmParent = oParent;
      oFsm_0033_0035 = new Fsm_0033_0035( this );
      TsmPI__Port = new TsmIPort_IDoor( this );
      mPSMessager = new TsmPSPort();
      oFsms = new TsmFsm[ 1 ];
      oFsms[ 0 ] = oFsm_0033_0035;
    }

    public override TsmInterfacePort GetProvidedInterface( string sPortName )
    {
      switch( sPortName )
      {
      case "Port" :
        return TsmPI__Port;
      default :
        break;
      }
      string s;
      s = "No port '" + sPortName + "' @ ( Xmi > Data > Protocols > DoorCheckProtocol > Server )";
      throw new TsmException( s );
    }

    public override void SetRequiredInterface( string sPortName, TsmInterfacePort oProvidedInterface )
    {
      switch( sPortName )
      {
      case "Port" :
        Port = (TsmIPort_ICbDoor) oProvidedInterface;
        Port.Source = this;
        return;
      default :
        break;
      }
      string s;
      s = "No port '" + sPortName + "' @ ( Xmi > Data > Protocols > DoorCheckProtocol > Server )";
      throw new TsmException( s );
    }

    public override void ExecuteTrigger( TsmTrigger oTrigger )
    {
      SnapCall = oTrigger.Snap();
      TsmHandler lHandler = new TsmHandler( this, oTrigger );
      oFsm_0033_0035.ExecuteTriggerFsm( lHandler );
      SnapCall = "";
      SnapState = null;
    }

     // ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Opened )
    public void Function_1008( TsmHandler oHandler )
    {
      Port.CbOpened(responseId);
    }

     // ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Closed )
    public void Function_1009( TsmHandler oHandler )
    {
      Port.CbClosed(responseId);
    }

     // ( ServerCheckPsm >> Closed ) => ( ServerCheckPsm >> Opening )
    public void Function_1010( TsmHandler oHandler )
    {
      TsmTrigger_IDoor___Open lTrigger = (TsmTrigger_IDoor___Open) oHandler.Trigger;
      int requestId = lTrigger.requestId;

      responseId=requestId;
    }

     // ( ServerCheckPsm >> Closing ) => ( ServerCheckPsm >> Opening )
    public void Function_1011( TsmHandler oHandler )
    {
      TsmTrigger_IDoor___Open lTrigger = (TsmTrigger_IDoor___Open) oHandler.Trigger;
      int requestId = lTrigger.requestId;

      responseId=requestId;
    }

     // ( ServerCheckPsm >> Opening ) => ( ServerCheckPsm >> Closing )
    public void Function_1012( TsmHandler oHandler )
    {
      TsmTrigger_IDoor___Close lTrigger = (TsmTrigger_IDoor___Close) oHandler.Trigger;
      int requestId = lTrigger.requestId;

      responseId=requestId;
    }

     // ( ServerCheckPsm >> Opened ) => ( ServerCheckPsm >> Closing )
    public void Function_1013( TsmHandler oHandler )
    {
      TsmTrigger_IDoor___Close lTrigger = (TsmTrigger_IDoor___Close) oHandler.Trigger;
      int requestId = lTrigger.requestId;

      responseId=requestId;
    }

    public override void TsmInitialise( object oObject )
    {
      TsmPI__Port.PortId = 34;
      TsmPI__Port.Messager = mPSMessager;
    }

    public override void TsmConnect( object oObject )
    {
      mPSMessager.Target = this;
    }

    public override void TsmPrepare( object oObject )
    {
      TsmHandler lHandler = new TsmHandler( this );
      lHandler.Action = TsmHandlerAction.ENTER;
      oFsm_0033_0035.ExecuteHandler( lHandler );
    }
  }

   // ( Xmi > Data > Protocols > DoorCheckProtocol > DoorCheckProtocol )
  public class Com_0005_0049 : TsmPComponent
  {
    private Cla_0005_0009 InsClient; // ( Xmi > Data > Protocols > DoorCheckProtocol > Client > InsClient )
    private Cla_0005_0033 InsServer; // ( Xmi > Data > Protocols > DoorCheckProtocol > Server > InsServer )

    public Com_0005_0049( TsmBase oParent, string sInstanceName )
    {
      TsmName = sInstanceName;
      TsmParent = oParent;
      InsClient = new Cla_0005_0009( this, "InsClient" );
      InsClient.IsMock = true;
      InsServer = new Cla_0005_0033( this, "InsServer" );
      InsServer.IsMock = true;
      mNrClasses = 2;
      mClasses = new TsmClass[ 2 ];
      mClasses[ 0 ] = InsClient;
      mClasses[ 1 ] = InsServer;
    }

    public override void TsmConnect( object oObject )
    {
      DoAssembly( InsClient, "Port", InsServer, "Port" );
      DoAssembly( InsServer, "Port", InsClient, "Port" );
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Protocols > DoorCheckProtocol )
   ********************************************************************/

   // ( Xmi > Data > Protocols > DoorCheckProtocol )
  public class Pac_0004_0005 : TsmPackage
  {
    public Pac_0004_0005( TsmBase oParent )
    {
      TsmName = "DoorCheckProtocol";
      TsmParent = oParent;
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Protocols )
   ********************************************************************/

   // ( Xmi > Data > Protocols )
  public class Pac_0001_0004 : TsmPackage
  {
    public Pac_0001_0004( TsmBase oParent )
    {
      TsmName = "Protocols";
      TsmParent = oParent;
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > TismStereotypes )
   ********************************************************************/

   // ( Xmi > Data > TismStereotypes )
  public class Pac_0001_0050 : TsmPackage
  {
    public Pac_0001_0050( TsmBase oParent )
    {
      TsmName = "TismStereotypes";
      TsmParent = oParent;
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Architecture > Sequence Diagrams )
   ********************************************************************/

   // ( Xmi > Data > Architecture > Sequence Diagrams )
  public class Pac_0051_0052 : TsmPackage
  {
    public Pac_0051_0052( TsmBase oParent )
    {
      TsmName = "Sequence Diagrams";
      TsmParent = oParent;
    }
  }

  /********************************************************************
   * PACKAGE: ( Xmi > Data > Architecture )
   ********************************************************************/

   // ( Xmi > Data > Architecture )
  public class Pac_0001_0051 : TsmPackage
  {
    public Pac_0001_0051( TsmBase oParent )
    {
      TsmName = "Architecture";
      TsmParent = oParent;
    }
  }

   // ( Xmi )
  public class TsmSystem : TsmExecComponent
  {
    private Com_0005_0049 DoorCheckProtocol; // ( Xmi > Data > Protocols > DoorCheckProtocol > DoorCheckProtocol )

    public TsmSystem( TsmBase oParent )
    {
      TsmName = "Xmi";
      TsmParent = oParent;
      mNrComponents = 1;
      mComponents = new TsmComponent[ 1 ];
      DoorCheckProtocol = new Com_0005_0049( null, "DoorCheckProtocol" );
      mComponents[ 0 ] = DoorCheckProtocol;
    }
  }
}
